@@ -1,6 +1,6 @@
 package Lorem::Element;
 {
-  $Lorem::Element::VERSION = '0.200';
+  $Lorem::Element::VERSION = '0.21';
 }
 
 use Moose;
@@ -49,6 +49,12 @@ has 'children' => (
     }
 );
 
+has 'name' => (
+    is => 'rw',
+    isa => 'Str',
+    default => '',
+);
+
 sub append_element {
     my ( $self, @elements ) = @_;
     
