@@ -1,6 +1,6 @@
 package Lorem::Role::Style::HasText;
 {
-  $Lorem::Role::Style::HasText::VERSION = '0.200';
+  $Lorem::Role::Style::HasText::VERSION = '0.21';
 }
 
 use Moose::Role;
@@ -10,6 +10,7 @@ use Lorem::Types qw(LoremStyleFontFamily LoremStyleFontStyle LoremStyleFontSize
 LoremStyleFontWeight LoremStyleFontVariant LoremStyleTextAlign LoremStyleTextAlign
 LoremStyleTextDecoration LoremStyleTextUnderline);
 
+use Lorem::Util qw( color2rgb );
 
 
 has 'font_family' => (
@@ -78,6 +79,9 @@ sub attr_list {
     $attr = Pango::AttrUnderline->new( $self->text_underline ) if $self->text_underline;
     $list->insert( $attr );
     
+    $attr = Pango::AttrForeground->new( color2rgb ( $self->color ) ) if $self->color;
+    $list->insert( $attr );
+    
     return $list;
 }
 
