@@ -1,6 +1,6 @@
 package Lorem::Surface::Pdf;
 {
-  $Lorem::Surface::Pdf::VERSION = '0.200';
+  $Lorem::Surface::Pdf::VERSION = '0.21';
 }
 
 use Moose;
@@ -8,8 +8,6 @@ use MooseX::SemiAffordanceAccessor;
 use MooseX::StrictConstructor;
 extends 'Lorem::Surface';
 
-use Gtk2;
-
 has 'width' => (
     is => 'rw',
     isa => 'Num',
@@ -35,7 +33,7 @@ sub print {
     $doc->set_height( $self->height );
     my $cr = Cairo::Context->create( $surface );
 
-    #&{$doc->builder_func}( $doc, $cr );
+    &{$doc->builder_func}( $doc, $cr ) if $doc->builder_func;
     
     my @pages = @{$doc->children};
 
